@@ -15,8 +15,8 @@ class MailAuthBackend(ModelBackend):
     signer = signing.UserSigner()
 
     def authenticate(self, request, token=None):
-        max_age = getattr(settings, 'LOGIN_URL_TIMEOUT', 60 * 15)
-        single_use = getattr(settings, 'LOGIN_TOKEN_SINGLE_USE', True)
+        max_age = getattr(settings, "LOGIN_URL_TIMEOUT", 60 * 15)
+        single_use = getattr(settings, "LOGIN_TOKEN_SINGLE_USE", True)
 
         try:
             user = self.signer.unsign(token, max_age=max_age, single_use=single_use)
@@ -32,6 +32,11 @@ class MailAuthBackend(ModelBackend):
         else:
             if self.user_can_authenticate(user):
                 return user
+            logger.warning(
+                "User '%s' is not allowed to authenticate.",
+                user,
+                exc_info=True,
+            )
 
     @classmethod
     def get_token(cls, user):
@@ -39,7 +44,4 @@ class MailAuthBackend(ModelBackend):
 
     @staticmethod
     def get_login_url(token):
-        return reverse(
-            'mailauth:login-token',
-            kwargs={'token': token}
-        )
+        return reverse("mailauth:login-token", kwargs={"token": token})
